Rem Execute latexmk.pl, searching for it in the PATH
Rem Assume perl is in the PATH.  If not, you should replace 'perl' by 
Rem the full pathname of the perl executable, e.g., 'C:\perl\bin\perl.exe'

perl -S latexmk.pl %1 %2 %3 %4 %5 %6 %7 %8 %9
